@@ -18,5 +18,5 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from .energy_handler import EnergyHandler
+from .energy_handler import EnergyHandler, UnconsistantSamplesError
 from .print_handler import PrintHandler
